@@ -72,17 +72,12 @@ class _SelectorItem(QGraphicsRectItem):
     def paint(self, p, option, widget):
         p.setPen(self.Color)
         p.setBrush(QBrush(Qt.NoBrush))
-        p.drawRect(self.rect().x(),self.rect().y(),self.rect().width(),self.rect().height())
+        p.drawRect(QRectF(self.rect().x(),self.rect().y(),self.rect().width(),self.rect().height()))
         return
         # Draw info text
         font = QFont("Arial",13)
         text = "%d selected."  % len(self.get_selected_nodes())
         textR = QFontMetrics(font).boundingRect(text)
-        if  self.rect().width() > textR.width() and \
-                self.rect().height() > textR.height()/2 and 0: # OJO !!!!
-            p.setPen(QPen(self.Color))
-            p.setFont(QFont("Arial",13))
-            p.drawText(self.rect().bottomLeft().x(),self.rect().bottomLeft().y(),text)
 
     def get_selected_nodes(self):
         selPath = QPainterPath()
@@ -169,7 +164,7 @@ class _GUI(QMainWindow):
         # Shows the whole tree by default
         #self.view.fitInView(self.scene.sceneRect(), Qt.KeepAspectRatio)
         splitter.setCollapsible(1, True)
-        splitter.setSizes([self.scene.sceneRect().width(), 10])
+        splitter.setSizes([int(self.scene.sceneRect().width()), 10])
 
         self.view.fitInView(0, 0, self.scene.sceneRect().width(), 200, Qt.KeepAspectRatio)
 
